/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.elasticsearch.test.disruption;

import org.elasticsearch.common.unit.TimeValue;
import org.elasticsearch.test.InternalTestCluster;

public interface ServiceDisruptionScheme {

    void applyToCluster(InternalTestCluster cluster);

    void removeFromCluster(InternalTestCluster cluster);

    void removeAndEnsureHealthy(InternalTestCluster cluster);

    void applyToNode(String node, InternalTestCluster cluster);

    void removeFromNode(String node, InternalTestCluster cluster);

    void startDisrupting();

    void stopDisrupting();

    void testClusterClosed();

    TimeValue expectedTimeToHeal();

}
